(define-module (ui users ajax)
    :use-module (alterator str)
    :use-module (alterator ajax)
    :use-module (alterator woo)
    :export (on-load))

(define (ui-reset-password)
  (form-update-value-list
    '("passwd_1" "passwd_2")
    '("/users" 'a "b")) ;;empty command
  (form-update-value "auto" #f)
  (ui-auto #f)
  (ui-generate))

(define (ui-read . name)
  (let ((name (if (pair? name) (car name) (form-value "name"))))
    (ui-reset-password)
    (form-update-value-list
      '("gecos" "home" "shell" "allow_su")
      (if name (woo-read-first "/users" 'name name) '("/users")))))

(define (ui-list . name)
  (let* ((data (woo-list "/users"))
	 (name (or (and (pair? name) (car name))
		   (and (pair? data) (woo-get-option (car data) 'name)))))
    (form-update-enum "name" data)
    (and name (form-update-value "name" name))
    (ui-read name)))

(define (ui-auto . auto)
  (let ((auto (if (pair? auto) (car auto) (form-value "auto"))))
    (form-update-visibility
      '("passwd_auto" "generate_button")
      auto)
    (form-update-visibility
      '("passwd_1" "passwd_2")
      (not auto))))

(define (ui-generate)
  (form-update-value-list
    '("passwd_auto")
    (car (woo "generate" "/users"))))

(define (ui-delete)
  (let ((name (form-value "name")))
    (if   (and (not-empty-string? name)
	       (form-confirm (string-append (_ "Do you really want to delete user ")
					    name
					    " ?")))
      (catch/message
	(lambda()
	  (woo-delete "/users/" 'name name 'language (form-value "language"))
	  (ui-list))))))


(define (ui-new)
  (let ((new_name (form-value "new_name")))
    (if (not-empty-string? new_name)
      (catch/message
	(lambda()
	  (woo-new "/users" 'new_name new_name 'language (form-value "language"))
	  (form-update-value "new_name" "")
	  (ui-list new_name))))))

(define (ui-write)
  (let ((name (form-value "name")))
    (if (not-empty-string? name)
      (catch/message
	(lambda()
	  (apply woo-write  "/users"
		 (form-value-list
		   '("name" "language" "home" "gecos" "shell" "allow_su"
		     "passwd_1" "passwd_2" "passwd_auto" "auto")))
	  (ui-read name))))))

(define (on-load)
  (form-update-enum "shell" (woo-list "/users/avail_shell"))
  (ui-list)

  (form-bind "name" "change" ui-read)
  (form-bind "auto" "change" ui-auto)
  (form-bind "generate_button" "click" ui-generate)

  (form-bind "delete_button" "click" ui-delete)
  (form-bind "apply_button" "click" ui-write)
  (form-bind "new_button" "click" ui-new))
